from usefulpy import runners, logic
from usefulpy.helpers import *

class NewUser(logic.BaseCommand):
  """
  Usage:
    useful.py user new <name> [--home=home] [-D]

  Options:
    -D, --dry    Print the commands to stdout
  """

  def run(self):
    runner = runners.BashRunner(self.arguments['--dry'])

    extra = " --home=\"%s\"" % self.arguments['--home'] if self.arguments['--home'] else ''
    runner.execute('adduser %s%s' % (self.arguments['<name>'], extra), requires_root=True)
